@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,6 +41,9 @@ FAILEDOPERATION_CLOUDAPIPROXYERROR = 'FailedOperation.CloudApiProxyError'
 # 创建集群，开通VPC网络权限失败。
 FAILEDOPERATION_CLUSTERCREATEVPCFAIL = 'FailedOperation.ClusterCreateVpcFail'
 
+# 本环境仅允许操作名称 %s 的集群
+FAILEDOPERATION_CLUSTEROPERATEENVILLEGALERROR = 'FailedOperation.ClusterOperateEnvIllegalError'
+
 # 查询集群失败。
 FAILEDOPERATION_CLUSTERQUERYFAILED = 'FailedOperation.ClusterQueryFailed'
 
@@ -89,7 +92,7 @@ FAILEDOPERATION_CONTAINERGROUPGROUPHASSTOP = 'FailedOperation.ContainergroupGrou
 # 调用 kube-api-server 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETEAPIINVOKEERROR = 'FailedOperation.ContainergroupKuberneteApiInvokeError'
 
-# 连接 kube-api-sever 失败。
+# 连接 kube-api-server 失败。
 FAILEDOPERATION_CONTAINERGROUPKUBERNETECONNECTERROR = 'FailedOperation.ContainergroupKuberneteConnectError'
 
 # 调用 kube-api-server 失败。
@@ -113,6 +116,9 @@ FAILEDOPERATION_DISPATCHCOMMONERROR = 'FailedOperation.DispatchCommonError'
 # 寻找独占配置中心相关指标异常
 FAILEDOPERATION_FINDMETRICSEXCLUSIVEERROR = 'FailedOperation.FindMetricsExclusiveError'
 
+# 网关通用异常:%s。
+FAILEDOPERATION_GATEWAYCOMMONERROR = 'FailedOperation.GatewayCommonError'
+
 # 远端访问错误: %s。
 FAILEDOPERATION_GATEWAYREMOTECALLERROR = 'FailedOperation.GatewayRemoteCallError'
 
@@ -629,6 +635,9 @@ INVALIDPARAMETERVALUE_CLUSTERCIDRCONFLICT = 'InvalidParameterValue.ClusterCidrCo
 # 集群命名已存在，请更换其他名称。
 INVALIDPARAMETERVALUE_CLUSTERNAMEEXIST = 'InvalidParameterValue.ClusterNameExist'
 
+# 本环境集群名称禁止以 %s 开头
+INVALIDPARAMETERVALUE_CLUSTERNAMEPREFIXILLEGALERROR = 'InvalidParameterValue.ClusterNamePrefixIllegalError'
+
 # 集群命名不能为空。
 INVALIDPARAMETERVALUE_CLUSTERNAMEREQUIRED = 'InvalidParameterValue.ClusterNameRequired'
 
@@ -1133,7 +1142,7 @@ RESOURCEINUSE_GROUPEXISTS = 'ResourceInUse.GroupExists'
 # 部署组在更新中 请稍后再执行该操作。
 RESOURCEINUSE_GROUPINOPERATION = 'ResourceInUse.GroupInOperation'
 
-# 实例已经存在。
+# 集群内有云主机,不允许删除集群。
 RESOURCEINUSE_INSTANCEEXISTS = 'ResourceInUse.InstanceExists'
 
 # 机器实例已经被使用。
@@ -1238,7 +1247,7 @@ UNAUTHORIZEDOPERATION_LICENSEUNAUTHORIZED = 'UnauthorizedOperation.LicenseUnauth
 # 缺少License。。
 UNAUTHORIZEDOPERATION_NOLICENSE = 'UnauthorizedOperation.NoLicense'
 
-# 用户无权限访问该接口。。
+# 用户无权限访问该接口。
 UNAUTHORIZEDOPERATION_NOPRIVILEGE = 'UnauthorizedOperation.NoPrivilege'
 
 # 批量操作数量超过限制:%s。
